deltabot: chat bots for deltachat
=================================

The ``deltabot`` Python package implements several facilities:

- a command line interface to initialize, configure and run bots

- an extension API to let your Chat bot add new commands,
  configuration and interact with incoming messages

deltabot uses the deltachat python package which
contains bindings with the deltachat core Rust-library.


getting started
---------------

.. toctree::
   :maxdepth: 2

   install

.. toctree::
   :hidden:

   links
   changelog
   api
   plugins

..
    Indices and tables
    ==================

    * :ref:`genindex`
    * :ref:`modindex`
    * :ref:`search`

